{{/* vim: set filetype=mustache: */}}
{{/*
Create a default fully qualified client name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
*/}}
{{- define "elasticsearch.client.fullname" -}}
{{ template "common.fullname" . }}-{{ .Values.client.name }}
{{- end -}}

{{/*
Create standard labels for client nodes.
*/}}
{{- define "elasticsearch.client.labels" -}}
{{ template "common.labels.standard" . }}
{{ template "common.labels.component" .Values.client.name }}
{{- end -}}

{{/*
Create selector labels for client nodes.
*/}}
{{- define "elasticsearch.client.selector" -}}
{{ template "common.labels.selector" . }}
{{ template "common.labels.component" .Values.client.name }}
{{- end -}}

{{/*
Create a default fully qualified data name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
*/}}
{{- define "elasticsearch.data.fullname" -}}
{{ template "common.fullname" . }}-{{ .Values.data.name }}
{{- end -}}

{{/*
Create standard labels for data nodes.
*/}}
{{- define "elasticsearch.data.labels" -}}
{{ template "common.labels.standard" . }}
{{ template "common.labels.component" .Values.data.name }}
{{- end -}}

{{/*
Create selector labels for data nodes.
*/}}
{{- define "elasticsearch.data.selector" -}}
{{ template "common.labels.selector" . }}
{{ template "common.labels.component" .Values.data.name }}
{{- end -}}

{{/*
Create a default fully qualified master name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
*/}}
{{- define "elasticsearch.master.fullname" -}}
{{ template "common.fullname" . }}-{{ .Values.master.name }}
{{- end -}}

{{/*
Create standard labels for master nodes.
*/}}
{{- define "elasticsearch.master.labels" -}}
{{ template "common.labels.standard" . }}
{{ template "common.labels.component" .Values.master.name }}
{{- end -}}

{{/*
Create selector labels for master nodes.
*/}}
{{- define "elasticsearch.master.selector" -}}
{{ template "common.labels.selector" . }}
{{ template "common.labels.component" .Values.master.name }}
{{- end -}}

{{/*
Create the name of the service account to use for the client component
*/}}
{{- define "elasticsearch.serviceAccountName.client" -}}
{{- if .Values.serviceAccounts.client.create -}}
    {{ default (include "elasticsearch.client.fullname" .) .Values.serviceAccounts.client.name }}
{{- else -}}
    {{ default "default" .Values.serviceAccounts.client.name }}
{{- end -}}
{{- end -}}

{{/*
Create the name of the service account to use for the data component
*/}}
{{- define "elasticsearch.serviceAccountName.data" -}}
{{- if .Values.serviceAccounts.data.create -}}
    {{ default (include "elasticsearch.data.fullname" .) .Values.serviceAccounts.data.name }}
{{- else -}}
    {{ default "default" .Values.serviceAccounts.data.name }}
{{- end -}}
{{- end -}}

{{/*
Create the name of the service account to use for the master component
*/}}
{{- define "elasticsearch.serviceAccountName.master" -}}
{{- if .Values.serviceAccounts.master.create -}}
    {{ default (include "elasticsearch.master.fullname" .) .Values.serviceAccounts.master.name }}
{{- else -}}
    {{ default "default" .Values.serviceAccounts.master.name }}
{{- end -}}
{{- end -}}

{{/*
plugin installer template
*/}}
{{- define "plugin-installer" -}}
- name: es-plugin-install
  image: {{ include "common.imagename" .Values.image }}
  imagePullPolicy: {{ .Values.image.pullPolicy }}
  securityContext:
    capabilities:
      add:
        - IPC_LOCK
        - SYS_RESOURCE
  command:
    - "sh"
    - "-c"
    - |
      {{- range .Values.cluster.plugins }}
      PLUGIN_NAME="{{ . }}"
      echo "Installing $PLUGIN_NAME..."
      if /usr/share/elasticsearch/bin/elasticsearch-plugin list | grep "$PLUGIN_NAME" > /dev/null; then
        echo "Plugin $PLUGIN_NAME already exists, skipping."
      else
        /usr/share/elasticsearch/bin/elasticsearch-plugin install -b $PLUGIN_NAME
      fi
      {{- end }}
  volumeMounts:
  - mountPath: /usr/share/elasticsearch/plugins/
    name: plugindir
  - mountPath: /usr/share/elasticsearch/config/elasticsearch.yml
    name: config
    subPath: elasticsearch.yml
{{- end -}}
