// DOM-10685: Fork of https://github.com/cerebrotech/platform-apps/blob/master/resources/deployer/data/configuration/salt/mongodb/scripts/CentralConfigTemplate.js

var defaultConfigEntries = [
  {'namespace': 'common', 'key': 'com.cerebro.domino.frontend.enableProjectTagging', 'value': 'true'},

  {'namespace': 'common', 'key': 'com.cerebro.domino.userHost', 'value': '{{- include "nucleus.urlProto" . }}{{ .Values.config.domain }}'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.dispatcher.url', 'value': '{{- include "nucleus.urlProto" . }}{{ .Values.config.domain }}'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.publicGitRepoHost', 'value': '{{- include "nucleus.urlProto" . }}{{ .Values.config.domain }}'},

  {'namespace': 'common', 'key': 'mongodb.default.user', 'value': '{{ .Values.config.mongo.username }}'},
  {'namespace': 'common', 'key': 'mongodb.default.password', 'value': '{{ .Values.config.mongo.password }}'},
  {'namespace': 'common', 'key': 'mongodb.default.db', 'value': '{{ .Values.config.mongo.database }}'},

  // TODO: legacy executor access -- these can be removed when we no longer support 3.6
  {{- $internalNucleusUri := default (printf "%s%s" (include "nucleus.urlProto" .) .Values.config.domain) .Values.config.internalNucleusUri }}

  {'namespace': 'role', 'name': 'executor', 'key': 'com.cerebro.domino.dispatcher.url', 'value': '{{- default $internalNucleusUri .Values.config.internalDispatcherUri }}'},
  {'namespace': 'role', 'name': 'executor', 'key': 'com.cerebro.domino.dispatcher.internalUrl', 'value': '{{- default $internalNucleusUri .Values.config.internalDispatcherUri }}'},
  {'namespace': 'role', 'name': 'executor', 'key': 'com.cerebro.domino.internalApiHost', 'value': '{{- $internalNucleusUri }}'},
  {'namespace': 'role', 'name': 'executor', 'key': 'com.cerebro.domino.internalGitRepoHost', 'value': '{{- default $internalNucleusUri .Values.config.internalGitRepoUri }}'},

  {'namespace': 'common', 'key': 'com.cerebro.domino.isCloudMode', 'value': '{{ .Values.config.cloudMode }}'},

{{- with .Values.config.tags }}
  {'namespace':'role','name':'dispatcher','key':'com.cerebro.domino.aws.customExecutorTagsAsJson','value':'{{ . }}'},
{{- end }}

  {'namespace':'common','key':'com.cerebro.domino.aws.instanceProfileName','value':'{{ .Values.config.aws.instanceProfileName }}'},
  {'namespace':'common','key':'com.cerebro.domino.aws.keyPairName','value':'{{ .Values.config.aws.keyPairName }}'},

{{- if .Values.config.cloudMode }}
  {'namespace':'common','key':'com.cerebro.domino.blobStorageMedium','value':'S3'},
  {'namespace':'common','key':'com.cerebro.domino.blobS3Region','value':'{{ .Values.config.s3.region }}'},
  {'namespace':'common','key':'com.cerebro.domino.blobS3Bucket','value':'{{ .Values.config.s3.bucket }}'},
  {{- with .Values.config.s3.sse_kms_key_id }}
  {'namespace':'common','key':'com.cerebro.domino.blobS3KmsKeyId','value':'{{ . }}'},
  {{- end }}
{{- else }}
  {'namespace': 'common', 'key': 'com.cerebro.domino.blobStorageMedium', 'value': 'FileSystem'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.blobFileRoot', 'value': '{{ .Values.config.blobStore.containerPath }}'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.computegrid.kubernetes.volume.blobStorePvc', 'value': '{{ default (printf "%s-%s" .Values.config.blobStore.claimName .Values.config.computeNamespace) .Values.config.compute.blobStorePvc }}'},
{{ end }}

{{- with .Values.config.compute.storageClass }}
  {'namespace': 'common', 'key': 'com.cerebro.domino.computegrid.kubernetes.volume.storageClass', 'value': '{{ . }}'},
{{ end }}

  {'namespace': 'common', 'key': 'play.http.parser.maxDiskBuffer', 'value': '5120M'},
  {'namespace': 'common', 'key': 'play.scrypto.secret', 'value': Math.random().toString(36).slice(2) + Math.random().toString(36).slice(2)},

{{- if .Values.config.externalSSL }}
  {'namespace': 'common', 'key': 'play.http.session.secure', 'value': 'true'},
  {'namespace': 'common', 'key': 'play.http.flash.secure', 'value': 'true'},
  {'namespace': 'common', 'key': 'securesocial.ssl', 'value': 'true'},
{{- else }}
  {'namespace': 'common', 'key': 'securesocial.ssl', 'value': 'false'},
{{- end }}

  {'namespace': 'common', 'key': 'securesocial.cookie.name', 'value': 'dominoAuth'},
  {'namespace': 'common', 'key': 'securesocial.cookie.domain', 'value': '{{ .Values.config.domain }}'},

  // SMTP
{{- range $key, $value := .Values.config.smtp }}
    {'namespace': 'common', 'key': 'smtp.{{ $key }}', 'value': '{{ $value }}'},
{{- end }}

{{- with .Values.config.notificationFromAddress }}
  {'namespace': 'common', 'key': 'com.cerebro.domino.email.notificationFromAddress', 'value': '{{ . }}'},
{{- end }}

  {'namespace': 'common', 'key': 'com.cerebro.domino.email.transportType', 'value': '{{ .Values.config.emailTransportType }}'},

{{- range $key, $value := .Values.config.proxy }}
  {{- if $value }}
    {'namespace': 'common', 'key': 'com.cerebro.domino.proxy.{{ $key }}': '{{ $value }}'},
  {{- end }}
{{- end }}

  //// Feature settings

  // Elasticsearch
  {'namespace': 'common', 'key': 'com.cerebro.domino.search.isElasticSearchEnabled', 'value': '{{ .Values.config.search.enabled }}'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.search.esClusterName', 'value': '{{ .Values.config.search.clusterName }}'},

  // Notebooks
  {'namespace': 'common', 'key': 'com.cerebro.domino.enableNotebookRendering', 'value': 'true'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.integrations.isIntegrationsEnabled', 'value': 'true'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.integrations.spark.isSparkConfigEnabled', 'value': 'true'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.integrations.spark.yarn.isEnabled', 'value': 'true'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.integrations.kerberos.isKerberosAuthenticationEnabled', 'value': 'true'},

  // Replicator
  {'namespace': 'role', 'name': 'dispatcher', 'key': 'com.cerebro.domino.replicator.accessMode', 'value': 'ReadOnlyMany'},
  {'namespace': 'role', 'name': 'dispatcher', 'key': 'com.cerebro.domino.replicator.cachedPath', 'value': '{{ .Values.config.sharedStorage.containerPath }}/replicatorStorage/cached'},
  {'namespace': 'role', 'name': 'dispatcher', 'key': 'com.cerebro.domino.replicator.preparedPath', 'value': '{{ .Values.config.sharedStorage.containerPath }}/replicatorStorage/prepared'},
  {'namespace': 'role', 'name': 'dispatcher', 'key': 'com.cerebro.domino.replicator.eventLogPath', 'value': '{{ .Values.config.sharedStorage.containerPath }}/replicatorStorage/event-log'},
  {'namespace': 'role', 'name': 'executor', 'key': 'com.cerebro.domino.replicator.accessMode', 'value': 'ReadWriteOnce'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.replicator.maxWaitForPrepare', 'value': '180'},

  // Kubernetes Replicator
  {'namespace': 'common', 'key': 'com.cerebro.domino.builder.job.model.useReplicator', 'value': 'true'},

  {'namespace': 'common', 'key': 'com.cerebro.domino.builder.job.replicator.persistentVolumeClaimName', 'value': 'replicator'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.builder.job.replicator.hostPath', 'value': ''},
  {'namespace': 'common', 'key': 'com.cerebro.domino.builder.job.replicator.mountPath', 'value': '/opt/docker/replicatorStorage'},

  // TODO pass in at runtime?
  {'namespace': 'common', 'key': 'com.cerebro.domino.superuser.username', 'value': '{{ .Values.config.superuser.username }}'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.superuser.apiKey', 'value': '{{ .Values.config.superuser.apiKey }}'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.builder.job.username', 'value': '{{ .Values.config.builderJob.username }}'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.builder.job.apiKey', 'value': '{{ .Values.config.builderJob.apiKey }}'},

  /// Deployer (not used in domino code afaict)
  {'namespace': 'common', 'key': 'com.cerebro.domino.deploy', 'value': '{{ .Values.config.stageName }}'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.stage', 'value': '{{ .Values.config.stageName }}'},

  //// Defaults

  {'namespace': 'common', 'key': 'com.cerebro.domino.frontend.enableNotebookEmbedding', 'value': 'true'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.supportAlerter.enableEmailSupportAlert', 'value': 'false'},
  {'namespace': 'common', 'key': 'logger.application', 'value': 'DEBUG'},
  {'namespace': 'role', 'name': 'dispatcher', 'key': 'com.cerebro.domino.dispatcher.maxRunsPerUserOnDefaultClass', 'value': '10'},
  {'namespace': 'role', 'name': 'dispatcher', 'key': 'com.cerebro.domino.dispatcher.instanceNamePrefix', 'value': ''},
  {'namespace': 'role', 'name': 'executor', 'key': 'com.cerebro.domino.executor.runsRoot', 'value': 'runs'},
  {'namespace': 'role', 'name': 'executor', 'key': 'com.cerebro.domino.executor.docker.configFileOrDirectory', 'value': '/home/domino/.docker'},
  {'namespace': 'role', 'name': 'executor', 'key': 'com.cerebro.domino.executor.maxIdleMaintenanceModeTimeInMinutes', 'value': '120'},

  {'namespace': 'common', 'key': 'com.cerebro.domino.centralLogging.mode', 'value': ''},

  {'namespace': 'common', 'key': 'com.cerebro.domino.frontend.allowHtmlFilesToRender', 'value': 'false'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.environments.allowAnyUserToEditEnvironments', 'value': 'true'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.executor.docker.logsFilterType', 'value': 'SinceFlag'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.frontend.restrictCollaboratorsToOrganizations', 'value': 'false'},

  {'namespace': 'common', 'key': 'com.cerebro.domino.frontend.notebookReverseProxy.isEnabled', 'value': 'true'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.frontend.notebookReverseProxy.publicAddress', 'value': 'https://{{ .Values.config.domain }}'},

  {'namespace': 'role', 'name': 'dispatcher', 'key': 'com.cerebro.domino.dispatcher.tickFrequency', 'value': '15'},
  {'namespace': 'role', 'name': 'dispatcher', 'key': 'com.cerebro.domino.dispatcher.clusterHealthMonitoring.isEnabled', 'value': 'false'},

  {'namespace': 'role', 'name': 'executor', 'key': 'com.cerebro.domino.environments.mountHostDockerInBuilderImage', 'value': 'false'},

  {'namespace': 'common', 'key': 'com.cerebro.domino.usePrivateAddressExternally', 'value': 'true'},

  {'namespace': 'common', 'key': 'com.cerebro.domino.endpoint.executionClass', 'value': 'default'},

  // Logjam
  {'namespace': 'common', 'key': 'com.cerebro.domino.executor.mothership.loggingToFluentD', 'value': 'true'},

  {'namespace': 'common', 'key': 'com.cerebro.domino.logjam.legacyMode', 'value': 'false'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.logjam.es.enabled', 'value': 'false'},

  {'namespace': 'common', 'key': 'com.cerebro.domino.logjam.redis.enabled', 'value': 'true'},

  {'namespace': 'common', 'key': 'com.cerebro.domino.logjam.s3.enabled', 'value': '{{ .Values.config.logjam.s3.enabled }}'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.logjam.s3.bucket', 'value': '{{ .Values.config.logjam.s3.bucket }}' },
  {'namespace': 'common', 'key': 'com.cerebro.domino.logjam.s3.rootPath', 'value': '{{ .Values.config.logjam.s3.path }}' },
  {{- with .Values.config.logjam.s3.sse_kms_key_id }}
  {'namespace':'common','key':'com.cerebro.domino.logjam.s3.sseKmsKeyId','value':'{{ . }}'},
  {{- end }}

  {'namespace': 'common', 'key': 'com.cerebro.domino.logjam.file.enabled', 'value': '{{ .Values.config.logjam.file.enabled }}'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.logjam.file.mount', 'value': '{{ ternary .Values.config.sharedStorage.containerPath .Values.config.blobStore.containerPath .Values.config.logjam.file.sharedStorage }}/logjam'},

  // Kubernetes Features
  {'namespace': 'role', 'name': 'dispatcher', 'key': 'com.cerebro.domino.modelmanager.messagebus.enabled', 'value': 'true'},
  {'namespace': 'role', 'name': 'frontend', 'key': 'com.cerebro.domino.runevents.messagebus.enabled', 'value': 'true'},

  {'namespace': 'common', 'key': 'com.cerebro.domino.environments.default.name', 'value': '{{ .Values.config.defaultEnvironment.name }}'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.environments.default.image', 'value': '{{ include "common.imagename" .Values.config.defaultEnvironment.image }}'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.environments.default.description', 'value': {{ .Values.config.defaultEnvironment.description | toJson }}},
  {'namespace': 'common', 'key': 'com.cerebro.domino.environments.default.propertiesUrl', 'value': 'file:///domino/default-workspace-props.yaml'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.environments.default.dockerfileInstructionsUrl', 'value': 'file:///domino/default-dockerfile-instructions'},

  //Docker build defaults
  {'namespace': 'common', 'key': 'com.cerebro.domino.builder.job.environment.buildCpuShares', 'value': '200'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.builder.job.environment.buildMemory', 'value': '2147483647'},
  
  // Kubernetes Setup
  {'namespace': 'common', 'key': 'com.cerebro.domino.kubernetes.isRunningInKubernetes', 'value': 'true'},

  // TODO: removing this is not yet supported as K8s executors pick it up
  {'namespace': 'role', 'name': 'executor', 'key': 'com.cerebro.domino.kubernetes.isRunningInKubernetes', 'value': 'false'},

  {'namespace': 'common', 'key': 'com.cerebro.domino.modelmanager.router.host', 'value': '{{ .Values.config.domain }}'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.modelmanager.router.port', 'value': '443'},

  {'namespace': 'common', 'key': 'com.cerebro.domino.modelmanager.instances.defaultNumber', 'value': '2'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.modelmanager.instances.maximumNumber', 'value': '32'},

{{- with .Values.config.dockerRegistry.externalHost }}
  {'namespace': 'role', 'name': 'executor', 'key': 'com.cerebro.domino.docker.registry.host', 'value': '{{ . }}'},
{{- end }}
{{- with .Values.config.dockerRegistry.externalPort }}
  {'namespace': 'role', 'name': 'executor', 'key': 'com.cerebro.domino.docker.registry.port', 'value': '{{ . }}'},
{{- end }}

  {'namespace': 'common', 'key': 'com.cerebro.domino.filecache.root', 'value': '{{ .Values.config.sharedStorage.containerPath }}/filecache'},

  //// Analytics

{{- with .Values.config.mixpanel }}
  {'namespace': 'common', 'key': 'com.cerebro.domino.frontend.analytics.mixpanel', 'value': '{{ .enabled }}'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.mixpanel.token', 'value': '{{ .token }}'},
{{- end }}

{{- with .Values.config.intercom }}
  {'namespace': 'common', 'key': 'com.cerebro.domino.frontend.analytics.intercom', 'value': '{{ .enabled }}'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.intercom.appId', 'value': '{{ .appId }}'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.intercom.secret', 'value': '{{ .secret }}'},
{{- end }}

  // TODO: this may be incorrect in specific cases (but: do we ever want it enabled anymore?)
  {'namespace': 'common', 'key': 'com.cerebro.domino.sshAccess.isEnabled', 'value': 'false'},

  {'namespace': 'common', 'key': 'com.cerebro.domino.frontend.workspaces.subdomains.scheme', 'value': 'https'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.frontend.workspaces.subdomains.suffix', 'value': '{{ .Values.config.nginx.workspaceSuffix }}'},
  {'namespace': 'common', 'key': 'com.cerebro.domino.frontend.workspaces.subdomains.baseDomain', 'value': '{{ .Values.config.domain }}'},

  // TODO is this correct in all cases?
  {'namespace': 'role', 'name': 'dispatcher', 'key': 'com.cerebro.domino.dispatcher.distributeRunsToLeastUtilizedExecutors', 'value': 'true'}
];

var configAlreadySet = db.config.count() > 0;

function safeEntryToString(entry) {
  return 'namespace=' + entry.namespace + ' name=' + entry.name + ' key=' + entry.key;
}

function processConfigEntries(entries) {
  for (i = 0; i < entries.length; i++) {
    var entry = entries[i];
    print('Inserting configuration entry: ' + safeEntryToString(entry));
    db.config.insert(entry);
  }
}

if (!configAlreadySet) {
  // XXX: this is a one-off to enable model manager by default for new installs.
  // This pattern SHOULD NOT be copied. Feature flags should actually be short-lived and removable, or moved to a config setting.
  print('Enabling model manager flag');
  db.feature_flag_overrides.update(
    {'fullyQualifiedName': 'featureflags.domain.FeatureFlags$ShortLived$ModelManagerPreviewEnabled$'},
    {'$setOnInsert': {'overrideValue': true}},
    {'upsert': true}
  );

  processConfigEntries(defaultConfigEntries);
}
