{{/* vim: set filetype=mustache: */}}

{{/*
Renders full specification for an Ingress object.

If no host is given, then this will just create a path-based routing rule. If a
tls secret is listed, then a tls-termination section will be rendered; a host
name MUST be provided as well. If you define ingress `paths` instead of `path`,
then multiple rules will be created for each path. You MUST define one of these
values.

You can override the default service name and port by adding the values
"overrideName" and "overridePort", respectively, to the context passed to this
macro.

Expected values: `ingress.path` or `ingress.paths`
Optional values: `ingress.annotations`, `ingress.hosts`, `ingress.host` and `ingress.tlsSecret`
*/}}
{{- define "common.ingress.fullspec" -}}

{{- if not .Values.ingress.paths -}}
{{- $_ := required ".Values.ingress.paths or .Values.ingress.path is required!" .Values.ingress.path -}}
{{- end -}}

{{- $ingressPaths := or .Values.ingress.paths (compact (list .Values.ingress.path)) -}}
{{- $ingressHosts := or .Values.ingress.hosts (compact (list .Values.ingress.host)) -}}
{{- $serviceName := default (include "common.fullname" .) .overrideName -}}
{{- $servicePort := default "http" .overridePort -}}

{{- if .Values.ingress.tlsSecret }}
tls:
- hosts:
  {{- with required ".Values.ingress.host or .hosts is required!" $ingressHosts }}
  - {{ . }}
  {{- end }}
  secretName: {{ .Values.ingress.tlsSecret }}
{{- end }}

rules:
{{- range $_, $path := $ingressPaths }}
  {{- if $ingressHosts }}
  {{- range $_, $host := $ingressHosts }}
  - host: {{ $host | quote }}
    http:
      paths:
      - path: {{ $path }}
        backend:
          serviceName: {{ $serviceName }}
          servicePort: {{ $servicePort }}
  {{- end }}
  {{- else }}
  - http:
      paths:
      - path: {{ $path }}
        backend:
          serviceName: {{ $serviceName }}
          servicePort: {{ $servicePort }}
  {{- end }}
{{- end }}

{{- end -}}
